// defining the width and height of the svg element.
let width = 700, height = 600

// create an svg with the previous width and height
let svg = d3.select("body").append("svg")
    .attr("width", width)
    .attr("height", height)

// create a mercator projection object
let europeProjection = d3.geoMercator()
  .center([ 13, 52 ])
  .scale([ width / 1.5 ])
  .translate([ width / 1.5, height / 2 ])

// a path generator which uses th geometry coordinates from the JSON
// which D3 can understand
let pathGenerator = null

// set the path generator to previous object
pathGenerator = d3.geoPath().projection(europeProjection)

// Set the europe countries GEOJSON from URL
let geoJsonUrl = "https://gist.githubusercontent.com/spiker830/3eab0cb407031bf9f2286f98b9d0558a/raw/7edae936285e77be675366550e20f9166bed0ed5/europe_features.json"

// load the GEOJSON from URL
d3.json(geoJsonUrl).then(geojson => {
  // add a path for each country in europe
  svg.selectAll("path")
    .data(geojson.features)
    .enter()
    .append("path")
    .attr("d", pathGenerator)
    .attr("stroke", "black") // Border color
    .attr("fill", "#ffe084") // country color
})